@@ -1,4 +1,4 @@
-/* $Id: glibmm.h 322 2006-09-19 20:36:43Z murrayc $ */
+/* $Id: glibmm.h 508 2008-01-12 19:50:43Z murrayc $ */
 
 /* glibmm - a C++ wrapper for the GLib toolkit
  *
@@ -54,6 +54,7 @@
 #include <glibmm/propertyproxy.h>
 #include <glibmm/quark.h>
 #include <glibmm/random.h>
+#include <glibmm/regex.h>
 #include <glibmm/refptr.h>
 #include <glibmm/shell.h>
 #include <glibmm/signalproxy_connectionnode.h>
@@ -65,6 +66,7 @@
 #include <glibmm/threadpool.h>
 #include <glibmm/timer.h>
 #include <glibmm/timeval.h>
+#include <glibmm/uriutils.h>
 #include <glibmm/ustring.h>
 #include <glibmm/value.h>
 #include <glibmm/wrap.h>
